@@ -3,8 +3,8 @@ import sklearn
 # import lightgbm as lgb
 import xgboost as xgb
 
-def logistic_regression(**params):
-    model = sklearn.linear_model.LogisticRegression(**params["parameters"])
+def logistic_regression():
+    model = sklearn.linear_model.LogisticRegression()
     return model
 
 def svm_svc(**params):
