@@ -25,7 +25,7 @@ def parse_dataset(dataset):
                 dict["columns"].append({"name": column, "type": "categorical"})
                 continue
             try:
-                pd.to_datetime(dataset[column], infer_datetime_format=True)
+                pd.to_datetime(dataset[column], dayfirst=True)
                 dict["columns"].append({"name": column, "type": "datetime"})
                 continue
             except:
